@@ -1,7 +1,5 @@
-# -*- coding: utf-8 -*-
 import doctest
 import operator
-import sys
 from decimal import Decimal
 from fractions import Fraction
 from operator import eq
@@ -25,10 +23,10 @@ class MyDocTestRunner(doctest.DocTestRunner):
         )
 
 
-class TestApprox(object):
+class TestApprox:
     @pytest.fixture
     def plus_minus(self):
-        return u"\u00b1" if sys.version_info[0] > 2 else u"+-"
+        return "\u00b1"
 
     def test_repr_string(self, plus_minus):
         tol1, tol2, infr = "1.0e-06", "2.0e-06", "inf"
@@ -498,7 +496,7 @@ class TestApprox(object):
         assert approx(expected, rel=5e-8, abs=0) != actual
 
     def test_generic_sized_iterable_object(self):
-        class MySizedIterable(object):
+        class MySizedIterable:
             def __iter__(self):
                 return iter([1, 2, 3, 4])
 
