@@ -1,13 +1,8 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
 import pytest
-from _pytest.main import EXIT_NOTESTSCOLLECTED
+from _pytest.main import ExitCode
 
 
-class SessionTests(object):
+class SessionTests:
     def test_basic_testitem_events(self, testdir):
         tfile = testdir.makepyfile(
             """
@@ -76,7 +71,7 @@ class SessionTests(object):
         values = reprec.getfailedcollections()
         assert len(values) == 1
         out = str(values[0].longrepr)
-        assert out.find(str("not python")) != -1
+        assert out.find("not python") != -1
 
     def test_exit_first_problem(self, testdir):
         reprec = testdir.inline_runsource(
@@ -335,7 +330,7 @@ def test_sessionfinish_with_start(testdir):
     """
     )
     res = testdir.runpytest("--collect-only")
-    assert res.ret == EXIT_NOTESTSCOLLECTED
+    assert res.ret == ExitCode.NO_TESTS_COLLECTED
 
 
 @pytest.mark.parametrize("path", ["root", "{relative}/root", "{environment}/root"])
